
0.0.1 (2018-09-24)
++++++++++++++++++

- minimum viable product

1.0 (2020-10-16)
++++++++++++++++++

- first release including
    - query via lightkurve
    - light curve de-trending (with lightkurve and K2SC)
    - flare search
    - flare characterization
    - injection/recovery diagnostics
    - statistical analysis tools

1.0.1 (2021-02-20)
++++++++++++++++++

- fixed the lightcurve version to <2 
- altaipony.__version__ now returns a version number


2.0 (2021-05-11)
++++++++++++++++++

- now available
    - compatibility with lightcurve >2
    - docs subpage added for de-trending
    - experimental detrending function provided
    
2.0.1 (2021-06-29)
++++++++++++++++++    

- fixed links in the README
- JOSS version
